@@ -2,7 +2,6 @@ import logging
 
 from luxtronik.datatypes import *
 
-logging.basicConfig(level="WARNING")
 LOGGER = logging.getLogger("Luxtronik.Parameters")
 
 
@@ -1131,6 +1130,11 @@ class Parameters:
         1117: Unknown("Unknown_Parameter_1117"),
         1118: Unknown("Unknown_Parameter_1118"),
         1119: Unknown("Unknown_Parameter_1119"),
+        1120: Unknown("Unknown_Parameter_1120"),
+        1121: Unknown("Unknown_Parameter_1121"),
+        1122: Unknown("Unknown_Parameter_1122"),
+        1123: Unknown("Unknown_Parameter_1123"),
+        1124: Unknown("Unknown_Parameter_1124"),
     }
 
     def __init__(self, safe=True):
