@@ -2,7 +2,6 @@ import logging
 
 from luxtronik.datatypes import Unknown
 
-logging.basicConfig(level="WARNING")
 LOGGER = logging.getLogger("Luxtronik.Visibilities")
 
 
@@ -356,6 +355,14 @@ class Visibilities:
         343: Unknown("Unknown_Visibility_343"),
         344: Unknown("Unknown_Visibility_344"),
         345: Unknown("Unknown_Visibility_345"),
+        346: Unknown("Unknown_Visibility_346"),
+        347: Unknown("Unknown_Visibility_347"),
+        348: Unknown("Unknown_Visibility_348"),
+        349: Unknown("Unknown_Visibility_349"),
+        350: Unknown("Unknown_Visibility_350"),
+        351: Unknown("Unknown_Visibility_351"),
+        352: Unknown("Unknown_Visibility_352"),
+        353: Unknown("Unknown_Visibility_353"),
     }
 
     def _parse(self, data):
